@@ -13,6 +13,8 @@ KEY_COMMAND = "command"
 KEY_COMPONENT = "component"
 KEY_COMPONENTSTATE = "componentstate"
 KEY_COMPONENTS = "components"
+KEY_CONNECTION = "connection"
+KEY_CONNECTED = "connected"
 KEY_DATA = "data"
 KEY_EFFECT = "effect"
 KEY_EFFECTS = "effects"
@@ -73,12 +75,19 @@ KEY_COMPONENTID_EFFECT = "EFFECT"
 KEY_COMPONENTID_SMOOTHING = "SMOOTHING"
 KEY_COMPONENTID_BLACKBORDER = "BLACKBORDER"
 KEY_COMPONENTID_FORWARDER = "FORWARDER"
-KEY_COMPONENTID_BOBLIGHTSERVER = "BOBLIGHTSERRVER"
+KEY_COMPONENTID_BOBLIGHTSERVER = "BOBLIGHTSERVER"
 KEY_COMPONENTID_GRABBER = "GRABBER"
 KEY_COMPONENTID_LEDDEVICE = "LEDDEVICE"
 KEY_COMPONENTID_V4L = "V4L"
 
+KEY_COMPONENTID_EXTERNAL_SOURCES = [
+    KEY_COMPONENTID_BOBLIGHTSERVER,
+    KEY_COMPONENTID_GRABBER,
+    KEY_COMPONENTID_V4L,
+]
+
 DEFAULT_INSTANCE = 0
 DEFAULT_CONNECTION_RETRY_DELAY = 30
-DEFAULT_CONNECTION_TIMEOUT_SECS = 5
+DEFAULT_TIMEOUT_SECS = 5
 DEFAULT_ORIGIN = "hyperion-py"
+DEFAULT_PORT = 19444
